movegroup-package: movegroup: Visualizing and Quantifying Space Use Data for...

movegroup-packageR Documentation

movegroup: Visualizing and Quantifying Space Use Data for Groups of Animals

Description

logo

Offers an easy and automated way to scale up individual-level space use analysis to that of groups. Contains functions from the 'move' package to calculate either a dynamic Brownian bridge movement model or dynamic Bivariate Gaussian bridges from movement data for individual animals, as well as functions to visualize and quantify space use for individuals aggregated in groups. Originally written with passive acoustic telemetry in mind, this package also provides functionality to account for unbalanced acoustic receiver array designs, and satellite tag data.

Author(s)

Maintainer: Simon Dedman simondedman@gmail.com (ORCID)

Authors:


movegroup documentation built on July 2, 2026, 9:06 a.m.