stitchraster: Stitch together movegroup data individuals core and general...

View source: R/stitchraster.R

stitchrasterR Documentation

Stitch together movegroup data individuals core and general use areas

Description

If over-large datasets cause RAM crashes for movegroup, one can run batches of individuals in movegroup then join the individual saved area.ct csv files.

Usage

stitchraster(
  data = NULL,
  ID = NULL,
  absVolumeAreaSaveName = "VolumeArea_AbsoluteScale.csv",
  savedir = tempdir()
)

Arguments

data

Data frame object containing the data. Requires columns Lat Lon Datetime ID and potentially a grouping column (not currently implemented, email to request). Column names specified in later parameters.

ID

Name of animal tag ID column in data. "Character".

absVolumeAreaSaveName

File name plus extension where UD estimates are saved. Default "VolumeArea_AbsoluteScale.csv".

savedir

Save outputs to a temporary directory (default) else change to desired directory e.g. "/home/me/folder". Do not use getwd() for this. Do NOT include terminal slash. Directory must exist. Default tempdir().

Details

See www.GitHub.com/SimonDedman/movegroup for issues, feedback, and development suggestions. Install 'move' development version with: remotes::install_git('https://gitlab.com/bartk/move.git')

Parameters values should match those used in movegroup.

Value

Calculated volume area estimates for 50 and 95pct contours csv.

Author(s)

Simon Dedman, simondedman@gmail.com


movegroup documentation built on July 2, 2026, 9:06 a.m.