| stitchraster | R Documentation |
If over-large datasets cause RAM crashes for movegroup, one can run batches of individuals in movegroup then join the individual saved area.ct csv files.
stitchraster(
data = NULL,
ID = NULL,
absVolumeAreaSaveName = "VolumeArea_AbsoluteScale.csv",
savedir = tempdir()
)
data |
Data frame object containing the data. Requires columns Lat Lon Datetime ID and potentially a grouping column (not currently implemented, email to request). Column names specified in later parameters. |
ID |
Name of animal tag ID column in data. "Character". |
absVolumeAreaSaveName |
File name plus extension where UD estimates are saved. Default "VolumeArea_AbsoluteScale.csv". |
savedir |
Save outputs to a temporary directory (default) else change to desired directory e.g. "/home/me/folder". Do not use getwd() for this. Do NOT include terminal slash. Directory must exist. Default tempdir(). |
See www.GitHub.com/SimonDedman/movegroup for issues, feedback, and development suggestions. Install 'move' development version with: remotes::install_git('https://gitlab.com/bartk/move.git')
Parameters values should match those used in movegroup.
Calculated volume area estimates for 50 and 95pct contours csv.
Simon Dedman, simondedman@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.